$set 3 #Configmenu

$ #ConfigOptions
# Konfigurcijas Opcijas
$ #FocusModel
# Fokusans Modelis
$ #WindowPlacement
# Loga Novietojums
$ #ImageDithering
# Attla Tonana
$ #OpaqueMove
# Necaurredzama Loga Prvietoana
$ #FullMax
# Pilna Maksimizcija
$ #FocusNew
# Fokust Jaunos Logus
$ #DisableBindings
# Deaktivizt Sasaistes ar Ritslga taustiu
$ #FocusLast
# Fokust Logu pie Darba vietas maias
$ #ClickToFocus
# Klikis, lai Fokustu
$ #SloppyFocus
# Nevga Fokusana
$ #AutoRaise
# Auto Pacelana
$ #ClickRaise
# Klikis Pace
$ #SmartRows
# Gudr Novietoana (Rinds)
$ #SmartCols
# Gudr Novietoana (Kolonns)
$ #Cascade
# Kaskdes Novietoana
$ #LeftRight
# No Kreiss un Labo
$ #RightLeft
# No Labs uz Kreiso
$ #TopBottom
# No Augas uz Leju
$ #BottomTop
# No Lejas uz Augu
$ #NoDithering
# Do not dither images
$ #OrderedDithering
# Use fast dither
$ #FloydSteinbergDithering
# Use high-quality dither
